# coding: utf-8

# flake8: noqa

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#operation/v1GetSatelliteTargets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#operation/v1CreateOrganizationTarget) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#operation/v1CreateWebhookConfiguration) endpoint to receive TDMs automatically (preferred) or use the [tdms](#operation/v1GetTdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.1905
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.3.1905"

# import apis into sdk package
from ourskyai_sda_api.api.default_api import DefaultApi

# import ApiClient
from ourskyai_sda_api.api_response import ApiResponse
from ourskyai_sda_api.api_client import ApiClient
from ourskyai_sda_api.configuration import Configuration
from ourskyai_sda_api.exceptions import OpenApiException
from ourskyai_sda_api.exceptions import ApiTypeError
from ourskyai_sda_api.exceptions import ApiValueError
from ourskyai_sda_api.exceptions import ApiKeyError
from ourskyai_sda_api.exceptions import ApiAttributeError
from ourskyai_sda_api.exceptions import ApiException

# import models into sdk package
from ourskyai_sda_api.models.astrometric_offsets import AstrometricOffsets
from ourskyai_sda_api.models.empty_success import EmptySuccess
from ourskyai_sda_api.models.filter_type import FilterType
from ourskyai_sda_api.models.observation_result import ObservationResult
from ourskyai_sda_api.models.orbit_type import OrbitType
from ourskyai_sda_api.models.successful_create import SuccessfulCreate
from ourskyai_sda_api.models.tracking_type import TrackingType
from ourskyai_sda_api.models.v1_create_image_set_image_request import V1CreateImageSetImageRequest
from ourskyai_sda_api.models.v1_create_image_set_image_response import V1CreateImageSetImageResponse
from ourskyai_sda_api.models.v1_create_image_set_request import V1CreateImageSetRequest
from ourskyai_sda_api.models.v1_create_organization_target_request import V1CreateOrganizationTargetRequest
from ourskyai_sda_api.models.v1_get_satellite_targets_response import V1GetSatelliteTargetsResponse
from ourskyai_sda_api.models.v1_image_set import V1ImageSet
from ourskyai_sda_api.models.v1_image_set_image import V1ImageSetImage
from ourskyai_sda_api.models.v1_observation_sequence_result import V1ObservationSequenceResult
from ourskyai_sda_api.models.v1_observation_sequence_result_image_sets_inner import V1ObservationSequenceResultImageSetsInner
from ourskyai_sda_api.models.v1_organization_target import V1OrganizationTarget
from ourskyai_sda_api.models.v1_satellite_potential import V1SatellitePotential
from ourskyai_sda_api.models.v1_satellite_target import V1SatelliteTarget
from ourskyai_sda_api.models.v1_tdm import V1Tdm
from ourskyai_sda_api.models.v1_update_email_configuration_request import V1UpdateEmailConfigurationRequest
from ourskyai_sda_api.models.v1_update_webhook_configuration_request import V1UpdateWebhookConfigurationRequest
from ourskyai_sda_api.models.v1_webhook_configuration import V1WebhookConfiguration
from ourskyai_sda_api.models.webhook_event import WebhookEvent
